# ArgEasy - Create amazing CLI programs

ArgEasy is a *command line* formatter made so that you can create CLI (command-line interface) Python programs **quickly and extremely easily**. In addition to being customizable, ArgEasy is optimized and can be used for large projects without any problems.

- [PyPI project](https://pypi.org/project/argeasy)
- [GitHub releases](https://github.com/jaedsonpys/argeasy/releases)
- [Learn how to use ArgEasy (documentation)](https://github.com/jaedsonpys/argeasy/blob/master/docs/LATEST.md)

## Starting with ArgEasy

First, let's install the latest version of the project using the PIP package manager with the command below:

```bash
pip install argeasy
```

If you prefer, you can install the project directly from the official GitHub repository using Git:

```bash
git clone https://github.com/jaedsonpys/argeasy
cd argeasy/
python3 setup.py install
```

After installation, you are ready to use all the features of the latest version of ArgEasy!

## License

```
MIT License
Copyright (c) 2023 Jaedson Silva
```

Please visit the [LICENSE](https://github.com/jaedsonpys/argeasy/blob/master/LICENSE) file for more details about the license used in this project.